@@ -51,6 +51,8 @@ class TemplateVolumeConfig(PluginTemplateExtension):
         lonely_drives = []
         drives_with_partition = []
         partitions = []
+        partition_dict = {
+        }
         for drive_id in drives:
             print(f"Right Page: {drive_id['drive']}")
             drives_id.append(drive_id['drive'])
@@ -67,10 +69,14 @@ class TemplateVolumeConfig(PluginTemplateExtension):
                                           type='Partition').count() == 0:
                 print(f"Right Page Lonely Drive: {drive}")
                 lonely_drives.append(drive)
+                partition_dict[str(drive.identifier)] = None
             else:
                 drives_with_partition.append(drive)
                 partitions.append(list(LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
                                                                   object_id=linux_device_drive.pk, type='Partition')))
+                partition_dict[str(drive.identifier)] = LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
+                                                                                   object_id=linux_device_drive.pk,
+                                                                                   type='Partition')
 
         amount_partitions = len(partitions)
         print(f"R Lonely Drives: {lonely_drives}")
@@ -82,7 +88,8 @@ class TemplateVolumeConfig(PluginTemplateExtension):
                 "lonely_drives": lonely_drives,
                 "drives": drives_with_partition,
                 "partitions": partitions,
-                "amount_partitions": amount_partitions
+                "amount_partitions": amount_partitions,
+                "partition_dict": partition_dict
             }
         )
 
@@ -103,7 +110,7 @@ class TemplateVolumeConfig(PluginTemplateExtension):
         partitions = Partition.objects.filter(drive_id__in=drives_id)
 
         return self.render(
-            "netbox_storage/inc/template_box.html",
+            "netbox_storage/inc/template_volume_box.html",
             extra_context={
                 "lonely_drives": lonely_drive,
                 "partitions": partitions,
